@@ -1,4 +1,4 @@
 from .structure_learning import hc, pc_stable, ges
 from .evaluation import f1, shd
-from .accessory import miss_mechanism, add_missing, dag2cpdag, from_bnlearn, to_bnlearn
+from .accessory import miss_mechanism, add_missing, dag2cpdag, from_bnlearn, to_bnlearn, pdag2dag
 from .score import score
\ No newline at end of file
